@@ -217,14 +217,14 @@ CmdlineParserCreator::do_update_arg (struct gengetopt_option *opt,
       stream << "break;";
       return;
     }
-  
+
   string indent_str (indent, ' ');
   const int offset = 4;
 
   update_arg_gen_class update_arg_gen;
   update_arg_gen.set_optarg(argstr);
   update_arg_gen.set_opt_var (opt->var_arg);
-  
+
   if (opt->multiple)
     {
       update_arg_gen.set_structure (string (opt->var_arg) + "_new");
@@ -301,7 +301,7 @@ CmdlineParserCreator::do_update_arg (struct gengetopt_option *opt,
     }
 
   update_arg_gen.generate_update_arg (stream, indent);
-    
+
   if (opt->arg_is_optional)
     {
       stream << endl;
@@ -382,7 +382,7 @@ _generate_option_arg(ostream &stream,
   string type = arg_types[opt->type];
   if (opt->multiple)
     type += "*";
-  
+
   option_arg_gen.set_type(type);
   option_arg_gen.set_flag_arg((opt->type == ARG_FLAG));
   option_arg_gen.set_desc(opt->desc);
@@ -517,7 +517,7 @@ CmdlineParserCreator::generate_usage_string(bool use_config_package)
     usage << gengetopt_package;
   else if (use_config_package)
     usage << "%s";
-    
+
   usage << " ";
 
   if ( long_help )
@@ -641,16 +641,16 @@ CmdlineParserCreator::generate_help_option_print(ostream &stream,
                                                  unsigned int indent)
 {
   OptionHelpList *option_list = generate_help_option_list();
-  
+
   print_help_string_gen_class print_gen;
-  
+
   for (OptionHelpList::const_iterator it = option_list->begin();
        it != option_list->end(); ++it)
     {
       print_gen.set_helpstring(*it);
       print_gen.generate_print_help_string(stream, indent);
     }
-  
+
   delete option_list;
 }
 
@@ -658,12 +658,12 @@ const string
 CmdlineParserCreator::generate_purpose()
 {
   string wrapped_purpose;
-  
+
   if (gengetopt_purpose != NULL)
     {
       wrap_cstr(wrapped_purpose, 0, 0, gengetopt_purpose);
     }
-    
+
   return wrapped_purpose;
 }
 
@@ -671,10 +671,10 @@ OptionHelpList *
 CmdlineParserCreator::generate_help_option_list()
 {
   OptionHelpList *option_list = new OptionHelpList;
-  
+
   long desc_col;
   struct gengetopt_option * opt;
-  
+
   int           type_len;
   const char   *type_str;
   ostringstream stream;
@@ -728,9 +728,9 @@ CmdlineParserCreator::generate_help_option_list()
             }
 
           group_string += opt->group_value + wrapped_desc;
-          
+
           option_list->push_back (group_string);
-          
+
           prev_group = opt->group_value;
         }
 
@@ -745,11 +745,11 @@ CmdlineParserCreator::generate_help_option_list()
             sec_string << "\\n";
 
           sec_string << opt->section << ":" ;
-          
+
           string wrapped_def;
           wrap_cstr(wrapped_def, 0, 0, sec_string.str());
           option_list->push_back(wrapped_def);
-          
+
           if (opt->section_desc)
             {
               string wrapped_desc ( 2, ' ');
@@ -830,11 +830,11 @@ CmdlineParserCreator::generate_help_option_list()
 
       generate_help_desc_print(stream, desc_col, opt_desc, def_val,
         (opt->acceptedvalues ? opt->acceptedvalues->toString() : ""));
-      
+
       option_list->push_back(stream.str());
       stream.str("");
     }
-    
+
   return option_list;
 }
 
@@ -995,7 +995,7 @@ CmdlineParserCreator::generate_list_def(ostream &stream, unsigned int indent)
                 generated_counter = true;
                 stream << endl;
               }
-          
+
               stream << indent_str;
               multiple_opt_list.set_arg_name (opt->var_arg);
               multiple_opt_list.generate_multiple_opt_list (stream, indent);
@@ -1197,7 +1197,9 @@ CmdlineParserCreator::generate_handle_help(ostream &stream,
 
      help_gen.generate_generic_option (stream, indent);
 
-     string indent_str (indent, ' ');
+     string indent_str (indent + 2, ' ');
+     stream << parser_function_name << "_free (&local_args_info);\n";
+     stream << indent_str;
      stream << "return 0;";
    }
  else
@@ -1224,7 +1226,9 @@ CmdlineParserCreator::generate_handle_version(ostream &stream,
 
      version_gen.generate_generic_option (stream, indent);
 
-     string indent_str (indent, ' ');
+     string indent_str (indent + 2, ' ');
+     stream << parser_function_name << "_free (&local_args_info);\n";
+     stream << indent_str;
      stream << "return 0;";
    }
  else
@@ -1297,19 +1301,19 @@ CmdlineParserCreator::handle_options(ostream &stream, unsigned int indent, bool
                 }
               else
                 multip_opt_gen.set_option_has_type(false);
-              
+
               generic_option_group_gen_class group_gen;
               if (opt->group_value)
                 {
                   multip_opt_gen.set_group_var_name (canonize_name (opt->group_value));
-                  multip_opt_gen.set_option_has_group(true);                  
+                  multip_opt_gen.set_option_has_group(true);
                 }
               else
                 multip_opt_gen.set_option_has_group(false);
 
               multip_opt_gen.set_option_not_string(opt->type != ARG_STRING);
               // for strings multi_token is copied directly, so it must not be freed.
-              
+
               multip_opt_gen.generate_multiple_option (stream, indent);
             }
           else
@@ -1321,12 +1325,12 @@ CmdlineParserCreator::handle_options(ostream &stream, unsigned int indent, bool
               option_gen.set_option_has_values (opt->acceptedvalues != 0);
 
               ostringstream update_stream;
-              
+
               generic_option_group_gen_class group_gen;
               if (opt->group_value)
                 {
                   ostringstream group_stream;
-                  
+
                   group_stream << endl;
                   group_stream << "  ";
                   group_gen.set_group_var_name
@@ -1338,11 +1342,11 @@ CmdlineParserCreator::handle_options(ostream &stream, unsigned int indent, bool
                 option_gen.set_update_group_count ("");
 
               do_update_arg (opt, update_stream, 0);
-              
+
               option_gen.set_update_arg(update_stream.str());
-              
+
               option_gen.generate_generic_option (stream, indent);
-              
+
               if (opt->type != ARG_NO && has_short)
                 generateBreak(stream, indent + 2);
             }
@@ -1352,7 +1356,7 @@ CmdlineParserCreator::handle_options(ostream &stream, unsigned int indent, bool
               stream << endl;
               stream << endl;
             }
-          
+
           if (first && !has_short)
             {
               first = false;
@@ -1361,7 +1365,7 @@ CmdlineParserCreator::handle_options(ostream &stream, unsigned int indent, bool
             }
         }
     }
-    
+
   if (! first && !has_short) // something has been generated
     {
       generateBreak(stream, indent);
@@ -1511,9 +1515,9 @@ CmdlineParserCreator::generate_list_free(ostream &stream,
 
   if (! has_multiple_options())
     return;
-  
+
   free_list_gen_class free_list;
-  
+
   foropt
     {
       if (opt->multiple && opt->type) {
