@@ -24,13 +24,18 @@
 #include "header.h"
 #include "c_source.h"
 
+#include <list>
+#include <string>
+
 #define TAB_LEN 2
 
 struct gengetopt_option;
 
+typedef std::list<std::string> OptionHelpList;
+
 class CmdlineParserCreator : public header_gen_class, public c_source_gen_class
 {
- protected:
+ protected:   
   char *parser_function_name;
   char *filename;
   char *args_info_name;
@@ -75,18 +80,18 @@ class CmdlineParserCreator : public header_gen_class, public c_source_gen_class
   int generate_header_file();
   int generate_source();
 
-  string generate_usage_string();
   string generate_getopt_string();
 
   // to be implemented in header_gen_class
   virtual void generate_option_arg(ostream &stream, unsigned int indent);
   virtual void generate_option_given(ostream &stream, unsigned int indent);
+  virtual void generate_option_values_decl(ostream &stream, unsigned int indent);
 
   // to be implemented in c_source_gen_class
-  virtual void generate_print_purpose(ostream &stream, unsigned int indent);
   virtual void generate_clear_arg(ostream &stream, unsigned int indent);
   virtual void generate_given_init(ostream &stream, unsigned int indent);
   virtual void generate_struct_def(ostream &stream, unsigned int indent);
+  virtual void generate_option_values(ostream &stream, unsigned int indent);
 
   virtual void generate_init_unamed(ostream &stream, unsigned int indent);
   virtual void generate_handle_help(ostream &stream, unsigned int indent);
@@ -104,9 +109,12 @@ class CmdlineParserCreator : public header_gen_class, public c_source_gen_class
   virtual void generate_reset_groups(ostream &stream, unsigned int indent);
 
   virtual void generate_free(ostream &stream, unsigned int indent);
+  virtual void generate_list_free(ostream &stream, unsigned int indent);
 
   void generateBreak(ostream &stream, unsigned int indent = 0);
-
+  
+  void handle_options(ostream &, unsigned int, bool has_short);
+  
  public:
 
   CmdlineParserCreator (char *function_name, char *struct_name,
@@ -123,6 +131,10 @@ class CmdlineParserCreator : public header_gen_class, public c_source_gen_class
   virtual void generate_list_def(ostream &stream, unsigned int indent);
   virtual void generate_multiple_fill_array(ostream &stream, unsigned int indent);
   virtual void generate_update_multiple_given(ostream &stream, unsigned int indent);
+  const string generate_purpose();
+  const string generate_usage_string(bool use_config_package = true);
+    
+  OptionHelpList *generate_help_option_list();
 };
 
 #endif /* _GM_H */
