@@ -166,14 +166,25 @@ has_values()
 }
 
 inline static int
-char_is_newline(const string &buf)
+char_is_newline(const string &buf, int &num_of_newlines)
 {
+  num_of_newlines = 0;
   string::size_type  notnewline = buf.find_first_not_of("\r\n");
-  if (notnewline)
-    return notnewline;
 
-  if (buf.size() > 1 && buf[0] == '\\' && buf[1] == 'n')
+  if (notnewline == string::npos) {
+    num_of_newlines = buf.size();
+    return num_of_newlines;
+  }
+
+  if (notnewline) {
+    num_of_newlines = notnewline;
+    return notnewline;
+  }
+
+  if (buf.size() > 1 && buf[0] == '\\' && buf[1] == 'n') {
+    num_of_newlines = 1;
     return 2;
+  }
 
   return 0;
 }
@@ -188,14 +199,17 @@ wrap_cstr( string& wrapped, unsigned int from_column, unsigned int second_indent
   const unsigned int second_line_column = from_column + second_indent;
   string indent (second_line_column, ' ');
   int newline_chars = 0;
+  int num_of_newlines = 0;
 
   while (*out_buf)
     {
       // check for a new line
       if (*out_buf)
-        if ((newline_chars = char_is_newline(out_buf)))
+        if ((newline_chars = char_is_newline(out_buf, num_of_newlines)))
           {
-            stream << "\\n";
+	    for (int i = 1; i <= num_of_newlines; ++i)
+	      stream << "\\n";
+
             out_buf += newline_chars;
 
             if (*out_buf)
@@ -215,8 +229,9 @@ wrap_cstr( string& wrapped, unsigned int from_column, unsigned int second_indent
 
       // search next whitespace, i.e., next word
       while ((*out_buf) && (*out_buf != ' ') &&
-             ! char_is_newline(out_buf))
+             ! char_is_newline(out_buf, num_of_newlines))
         {
+	  // num_of_newlines is not used.
           next_word += *out_buf++;
           next_space++;
         }
