@@ -13,14 +13,20 @@ int
 main (int argc, char **argv)
 {  
   int i;
+  int result = 0;
 
-  if (test_conf_parser_cmd_parser (argc, argv, &args_info) != 0)
-    exit(1) ;
+  if (test_conf_parser_cmd_parser (argc, argv, &args_info) != 0) {
+    result = 1;
+    goto stop;
+  }
 
   /* override cmd options, but do not initialize args_info, check for required options */
   if (test_conf_parser_cmd_parser_configfile
       (args_info.conf_file_arg, &args_info, 1, 0, 1) != 0) 
-    exit(1);
+    {
+      result = 1;
+      goto stop;
+    }
 
   printf ("value of required: %s\n", args_info.required_arg);
   printf ("value of string: %s\n", args_info.string_arg);
@@ -46,7 +52,8 @@ main (int argc, char **argv)
   printf ("noarg given %d times\n", args_info.noarg_given);
   printf ("noarg_noshort given %d times\n", args_info.noarg_noshort_given);
 
+ stop:
   test_conf_parser_cmd_parser_free (&args_info);
 
-  return 0;
+  return result;
 }
